@@ -1,8 +1,11 @@
 __version__ = "0.1.0"
 
+# optimizers first
+# rest
 from flax.linen import initializers
 
 from treex.module import *
+from treex.optimizer import *
 from treex.types import *
 
 from . import nn
