@@ -1,5 +1,6 @@
-from .linear import Linear
 from .batch_norm import BatchNorm
-from .sequence import sequence
-from .dropout import Dropout
 from .conv import Conv
+from .dropout import Dropout
+from .linear import Linear
+from .mlp import MLP
+from .sequence import Lambda, Sequence, sequence
